@@ -1,4 +1,4 @@
-/*	$OpenBSD: main.c,v 1.62 2020/04/16 11:25:43 claudio Exp $ */
+/*	$OpenBSD: main.c,v 1.69.4.1 2020/05/18 18:52:08 benno Exp $ */
 /*
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -44,6 +44,7 @@
 
 #include <sys/queue.h>
 #include <sys/socket.h>
+#include <sys/resource.h>
 #include <sys/stat.h>
 #include <sys/tree.h>
 #include <sys/types.h>
@@ -76,26 +77,6 @@
  */
 #define	TALSZ_MAX	8
 
-/*
- * Statistics collected during run-time.
- */
-struct	stats {
-	size_t	 tals; /* total number of locators */
-	size_t	 mfts; /* total number of manifests */
-	size_t	 mfts_fail; /* failing syntactic parse */
-	size_t	 mfts_stale; /* stale manifests */
-	size_t	 certs; /* certificates */
-	size_t	 certs_fail; /* failing syntactic parse */
-	size_t	 certs_invalid; /* invalid resources */
-	size_t	 roas; /* route origin authorizations */
-	size_t	 roas_fail; /* failing syntactic parse */
-	size_t	 roas_invalid; /* invalid resources */
-	size_t	 repos; /* repositories */
-	size_t	 crls; /* revocation lists */
-	size_t	 vrps; /* total number of vrps */
-	size_t	 uniqs; /* number of unique vrps */
-};
-
 /*
  * An rsync repository.
  */
@@ -160,6 +141,8 @@ const char	*bird_tablename = "ROAS";
 
 int	 verbose;
 
+struct stats	 stats;
+
 /*
  * Log a message to stderr if and only if "verbose" is non-zero.
  * This uses the err(3) functionality.
@@ -268,7 +251,7 @@ repo_lookup(int fd, struct repotab *rt, const char *uri)
 
 	i = rt->reposz - 1;
 
-	logx("%s/%s: loading", rp->host, rp->module);
+	logx("%s/%s: pulling from network", rp->host, rp->module);
 	io_simple_write(fd, &i, sizeof(size_t));
 	io_str_write(fd, rp->host);
 	io_str_write(fd, rp->module);
@@ -491,6 +474,16 @@ queue_add_tal(int fd, struct entityq *q, const char *file, size_t *eid)
 		err(1, "strdup");
 	buf = tal_read_file(file);
 
+	/* Record tal for later reporting */
+	if (stats.talnames == NULL)
+		stats.talnames = strdup(file);
+	else {
+		char *tmp;
+		asprintf(&tmp, "%s %s", stats.talnames, file);
+		free(stats.talnames);
+		stats.talnames = tmp;
+	}
+
 	/* Not in a repository, so directly add to queue. */
 	entityq_add(fd, q, nfile, RTYPE_TAL, NULL, NULL, NULL, 0, buf, eid);
 	/* entityq_add makes a copy of buf */
@@ -656,27 +649,28 @@ proc_rsync(char *prog, char *bind_addr, int fd, int noop)
 			 * Then we respond to the parent.
 			 */
 
-			if ((pid = waitpid(WAIT_ANY, &st, 0)) == -1)
-				err(1, "waitpid");
+			while ((pid = waitpid(WAIT_ANY, &st, WNOHANG)) > 0) {
+				for (i = 0; i < idsz; i++)
+					if (ids[i].pid == pid)
+						break;
+				assert(i < idsz);
 
-			for (i = 0; i < idsz; i++)
-				if (ids[i].pid == pid)
-					break;
-			assert(i < idsz);
+				if (!WIFEXITED(st)) {
+					warnx("rsync %s terminated abnormally",
+					    ids[i].uri);
+					rc = 1;
+				} else if (WEXITSTATUS(st) != 0) {
+					warnx("rsync %s failed", ids[i].uri);
+				}
 
-			if (!WIFEXITED(st)) {
-				warnx("rsync %s terminated abnormally",
-				    ids[i].uri);
-				rc = 1;
-			} else if (WEXITSTATUS(st) != 0) {
-				warnx("rsync %s failed", ids[i].uri);
+				io_simple_write(fd, &ids[i].id, sizeof(size_t));
+				free(ids[i].uri);
+				ids[i].uri = NULL;
+				ids[i].pid = 0;
+				ids[i].id = 0;
 			}
-
-			io_simple_write(fd, &ids[i].id, sizeof(size_t));
-			free(ids[i].uri);
-			ids[i].uri = NULL;
-			ids[i].pid = 0;
-			ids[i].id = 0;
+			if (pid == -1 && errno != ECHILD)
+				err(1, "waitpid");
 			continue;
 		}
 
@@ -729,7 +723,7 @@ proc_rsync(char *prog, char *bind_addr, int fd, int noop)
 				err(1, "pledge");
 			i = 0;
 			args[i++] = (char *)prog;
-			args[i++] = "-rlt";
+			args[i++] = "-rt";
 			args[i++] = "--delete";
 			if (bind_addr != NULL) {
 				args[i++] = "--address";
@@ -1248,11 +1242,6 @@ out:
 
 	free(b);
 
-	EVP_cleanup();
-	CRYPTO_cleanup_all_ex_data();
-	ERR_remove_thread_state(NULL);
-	ERR_free_strings();
-
 	exit(rc);
 }
 
@@ -1389,13 +1378,16 @@ main(int argc, char *argv[])
 	struct entity	*ent;
 	struct pollfd	 pfd[2];
 	struct repotab	 rt;
-	struct stats	 stats;
 	struct roa	**out = NULL;
 	char		*rsync_prog = RPKI_RSYNC_CMD;
 	char		*bind_addr = NULL;
 	const char	*cachedir = NULL;
 	const char	*tals[TALSZ_MAX];
 	struct vrp_tree	 v = RB_INITIALIZER(&v);
+	struct rusage	ru;
+	struct timeval	start_time, now_time;
+
+	gettimeofday(&start_time, NULL);
 
 	/* If started as root, priv-drop to _rpki-client */
 	if (getuid() == 0) {
@@ -1403,15 +1395,15 @@ main(int argc, char *argv[])
 
 		pw = getpwnam(RPKI_CLIENT_USER);
 		if (!pw)
-			errx(1, "no _rpki-client user to revoke to");
+			errx(1, "no %s user to revoke to", RPKI_CLIENT_USER);
 		if (setgroups(1, &pw->pw_gid) == -1 ||
 		    setresgid(pw->pw_gid, pw->pw_gid, pw->pw_gid) == -1 ||
 		    setresuid(pw->pw_uid, pw->pw_uid, pw->pw_uid) == -1)
 			err(1, "unable to revoke privs");
 
-		cachedir = RPKI_PATH_BASE_DIR;
-		outputdir = RPKI_PATH_OUT_DIR;
 	}
+	cachedir = RPKI_PATH_BASE_DIR;
+	outputdir = RPKI_PATH_OUT_DIR;
 
 	if (pledge("stdio rpath wpath cpath fattr proc exec unveil", NULL) == -1)
 		err(1, "pledge");
@@ -1486,7 +1478,6 @@ main(int argc, char *argv[])
 		err(1, "no TAL files found in %s", RPKI_PATH_TAL_DIR);
 
 	memset(&rt, 0, sizeof(struct repotab));
-	memset(&stats, 0, sizeof(struct stats));
 	TAILQ_INIT(&q);
 
 	/*
@@ -1614,7 +1605,7 @@ main(int argc, char *argv[])
 			assert(i < rt.reposz);
 			assert(!rt.repos[i].loaded);
 			rt.repos[i].loaded = 1;
-			logx("%s/%s: loaded", rt.repos[i].host,
+			logx("%s/%s: loaded from cache", rt.repos[i].host,
 			    rt.repos[i].module);
 			stats.repos++;
 			entityq_flush(proc, &q, &rt.repos[i]);
@@ -1661,7 +1652,18 @@ main(int argc, char *argv[])
 		rc = 1;
 	}
 
-	if (outputfiles(&v))
+	gettimeofday(&now_time, NULL);
+	timersub(&now_time, &start_time, &stats.elapsed_time);
+	if (getrusage(RUSAGE_SELF, &ru) == 0) {
+		stats.user_time = ru.ru_utime;
+		stats.system_time = ru.ru_stime;
+	}
+	if (getrusage(RUSAGE_CHILDREN, &ru) == 0) {
+		timeradd(&stats.user_time, &ru.ru_utime, &stats.user_time);
+		timeradd(&stats.system_time, &ru.ru_stime, &stats.system_time);
+	}
+
+	if (outputfiles(&v, &stats))
 		rc = 1;
 
 	logx("Route Origin Authorizations: %zu (%zu failed parse, %zu invalid)",
@@ -1693,6 +1695,6 @@ usage:
 	fprintf(stderr,
 	    "usage: rpki-client [-Bcfjnov] [-b sourceaddr] [-d cachedir]"
 	    " [-e rsync_prog]\n"
-	    "            [-T table] [-t tal] [outputdir]\n");
+	    "                   [-T table] [-t tal] [outputdir]\n");
 	return 1;
 }
